@@ -25,7 +25,7 @@ for src_file in config.enc/*; do
   # If the file is our secret, then decrypt it
   if echo "$src_filename" | grep -E "${secret_ext}$" &&
       test "$CONFIG_COPY_ONLY" != "TRUE"; then
-    sops --decrypt "$src_file" > "$target_file"
+    sops decrypt "$src_file" > "$target_file"
   # Otherwise, symlink to the original file
   else
     ln -s "../$src_file" "$target_file"
